==> slap-react-native-toggle-1.0.4.tgz: package/components/Select.js <==
import React, { Component } from 'react';
import { View, Text, Picker, Platform, Modal, TouchableWithoutFeedback } from 'react-native';
import PropTypes from 'prop-types';
import { SimpleLineIcons } from '@expo/vector-icons';
import _ from 'lodash';

import Button from '../components/Button';

export default class Select extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]).isRequired,
    label: PropTypes.string.isRequired,
    value: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.number
    ]),
    onChange: PropTypes.func,
    labelColor: PropTypes.string,
    marginTop: PropTypes.number,
    buttonBackgroundColor: PropTypes.string,
    buttonTextColor: PropTypes.string,
    name: PropTypes.string
  };

  static defaultProps = {
    value: '',
    onChange: () => {},
    labelColor: '#3c4f5e',
    marginTop: 0,
    buttonBackgroundColor: '#1d1d1d',
    buttonTextColor: '#ffffff',
    name: ''
  };

  state = {
    isModalVisible: false,
    value: this.props.value.toString(),
    index: 0
  };

  onPressItemLabel = () => {
    this.setState({
      isModalVisible: true
    });
  };

  onPressSelect = () => {
    this.props.onChange(this.state.value, this.state.index, this.props.name);

    this.setState({
      isModalVisible: false
    });
  };

  onPressCancel = () => {
    this.setState({
      isModalVisible: false,
      value: this.props.value
    });
  };

  onChange = (value, index) => {
    if (Platform.OS == 'android') {
      this.props.onChange(value, index, this.props.name);
    }
    else {
      this.setState({
        value: value,
        index: index
      });
    }
  };

  render() {
    if (Platform.OS == 'android') {
      return (
        <View style={{ marginTop: this.props.marginTop, height: 60, flexDirection: 'row' }}>
          <View style={{ flex: 1, justifyContent: 'center' }}>
            <Text style={{ color: this.props.labelColor }}>{ this.props.label }</Text>
          </View>
          <View style={{ flex: 2, justifyContent: 'center' }}>
            <Picker
              selectedValue={this.props.value.toString()}
              onValueChange={this.onChange}
            >
              { this.props.children }
            </Picker>
          </View>
        </View>
      );
    }
    else {
      let index = _.findIndex(this.props.children, (child) => {
        return child.props.value == this.props.value;
      });

      if (index == -1) {
        index = 0;
      }

      const label = this.props.children[index].props.label;

      return (
        <View style={{ marginTop: this.props.marginTop, height: 60, flexDirection: 'row' }}>
          <Modal
            animationType="fade"
            transparent
            visible={this.state.isModalVisible}
          >
            <View style={{ flex: 1, justifyContent: 'center', backgroundColor: 'rgba(0, 0, 0, 0.5)' }}>
              <View style={{ height: 300, paddingHorizontal: 30 }}>
                <View style={{ backgroundColor: '#fcfcfc', borderRadius: 5 }}>
                  <View style={{ paddingHorizontal: 30 }}>
                    <Picker
                      selectedValue={this.state.value}
                      onValueChange={this.onChange}
                    >
                      { this.props.children }
                    </Picker>
                  </View>
                  <Text style={{ position: 'absolute', top: 20, left: 20 }}>{ this.props.label }</Text>
                  <TouchableWithoutFeedback onPress={this.onPressCancel}>
                    <View style={{ width: 60, height: 60, position: 'absolute', top: 0, right: 0 }}>
                      <Text style={{ color: '#007aff', position: 'absolute', top: 20, right: 20 }}>취소</Text>
                    </View>
                  </TouchableWithoutFeedback>
                  <View style={{ paddingHorizontal: 50 }}>
                    <Button backgroundColor={this.props.buttonBackgroundColor} textColor={this.props.buttonTextColor} onPress={this.onPressSelect}>선택</Button>
                  </View>
                  <View style={{ height: 20 }} />
                </View>
              </View>
            </View>
          </Modal>
          <View style={{ flex: 1, justifyContent: 'center' }}>
            <Text>{ this.props.label }</Text>
          </View>
          <TouchableWithoutFeedback onPress={this.onPressItemLabel}>
            <View style={{ flex: 2, flexDirection: 'row' }}>
              <View style={{ flex: 1, justifyContent: 'center' }}>
                <Text style={{ color: this.props.labelColor }}>{ label }</Text>
              </View>
              <View style={{ width: 60, height: 60, alignItems: 'center', justifyContent: 'center' }}>
                <SimpleLineIcons name="arrow-down" size={23} color="#3c4f5e" />
              </View>
            </View>
          </TouchableWithoutFeedback>
        </View>
      );
    }
  }
}

==> slap-react-native-toggle-3.0.3.tgz: package/components/Select.js <==
import React, { Component } from 'react';
import { View, Text, Picker, Platform, Modal, TouchableWithoutFeedback } from 'react-native';
import PropTypes from 'prop-types';
import SimpleLineIcons from 'react-native-vector-icons/SimpleLineIcons';

import Button from '../components/Button';

export default class Select extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]).isRequired,
    label: PropTypes.string,
    value: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.number
    ]),
    onChange: PropTypes.func,
    labelColor: PropTypes.string,
    marginTop: PropTypes.number,
    buttonColor: PropTypes.string,
    buttonTextColor: PropTypes.string,
    name: PropTypes.string
  };

  static defaultProps = {
    label: '',
    value: '',
    onChange: () => {},
    labelColor: '#4d4d4d',
    marginTop: 0,
    buttonColor: '#4d4d4d',
    buttonTextColor: '#ffffff',
    name: ''
  };

  state = {
    isModalVisible: false,
    value: this.props.value.toString()
  };

  componentWillReceiveProps(nextProps) {
    this.setState({
      value: nextProps.value.toString()
    });
  }

  onPressLabel = () => {
    this.setState({
      isModalVisible: true
    });
  };

  onPressSelect = () => {
    this.props.onChange(this.state.value, this.props.name);

    this.setState({
      isModalVisible: false
    });
  };

  onPressCancel = () => {
    this.setState({
      isModalVisible: false,
      value: this.props.value
    });
  };

  onChange = (value) => {
    if (Platform.OS == 'android') {
      this.props.onChange(value, this.props.name);
    }
    else if (Platform.OS == 'ios') {
      this.setState({
        value: value
      });
    }
  };

  render() {
    if (Platform.OS == 'android') {
      return (
        <View style={{ marginTop: this.props.marginTop, height: 60, flexDirection: 'row' }}>
          <View style={{ flex: 1, justifyContent: 'center' }}>
            <Text style={{ color: this.props.labelColor }}>{ this.props.label }</Text>
          </View>
          <View style={{ flex: 2, justifyContent: 'center' }}>
            <Picker
              selectedValue={this.props.value.toString()}
              onValueChange={this.onChange}
            >
              { this.props.children }
            </Picker>
          </View>
        </View>
      );
    }
    else if (Platform.OS == 'ios') {
      let picker = this.props.children.find((child) => {
        return child.props.value == this.props.value;
      });

      let label = null;

      if (picker) {
        label = picker.props.label;
      }
      else {
        label = this.props.children[0].props.value;
      }

      return (
        <View style={{ marginTop: this.props.marginTop, height: 60, flexDirection: 'row' }}>
          <Modal
            animationType="fade"
            transparent
            visible={this.state.isModalVisible}
          >
            <View style={{ flex: 1, justifyContent: 'center', backgroundColor: 'rgba(0, 0, 0, 0.5)' }}>
              <View style={{ height: 300, paddingHorizontal: 30 }}>
                <View style={{ backgroundColor: '#ffffff', borderRadius: 5 }}>
                  <View style={{ paddingHorizontal: 30 }}>
                    <Picker
                      selectedValue={this.state.value}
                      onValueChange={this.onChange}
                    >
                      { this.props.children }
                    </Picker>
                  </View>
                  <View style={{ position: 'absolute', width: 150, height: 60, justifyContent: 'center' }}>
                    <Text style={{ marginLeft: 30 }}>{ this.props.label }</Text>
                  </View>
                  <TouchableWithoutFeedback onPress={this.onPressCancel}>
                    <View style={{ position: 'absolute', right: 0, width: 60, height: 60, justifyContent: 'center', alignItems: 'flex-end' }}>
                      <Text style={{ marginRight: 30, color: '#007aff' }}>취소</Text>
                    </View>
                  </TouchableWithoutFeedback>
                  <View style={{ paddingHorizontal: 50 }}>
                    <Button buttonColor={this.props.buttonColor} textColor={this.props.buttonTextColor} onPress={this.onPressSelect}>선택</Button>
                  </View>
                  <View style={{ height: 20 }} />
                </View>
              </View>
            </View>
          </Modal>
          <View style={{ flex: 1, justifyContent: 'center' }}>
            <Text style={{ color: this.props.labelColor }}>{ this.props.label }</Text>
          </View>
          <TouchableWithoutFeedback onPress={this.onPressLabel}>
            <View style={{ flex: 2, flexDirection: 'row' }}>
              <View style={{ flex: 1, justifyContent: 'center' }}>
                <Text>{ label }</Text>
              </View>
              <View style={{ width: 60, height: 60, alignItems: 'center', justifyContent: 'center' }}>
                <SimpleLineIcons name="arrow-down" size={23} color="#4d4d4d" />
              </View>
            </View>
          </TouchableWithoutFeedback>
        </View>
      );
    }
  }
}
